rree.generator <- function (n = 100, p = 20, type="rgig", seed=0, beta.true, x.sigma, x, sd.lnorm=1, outlier.ratio=0.1, outlier.par=c(2.5,0.1)){
	set.seed(seed)
	index <- rbinom(n,1,outlier.ratio)
	n.true <- n - sum(index)
	n.cont <- sum(index)
	if(missing(beta.true)) beta.true <- rep(1/(p+1),p+1)
	if(missing(x.sigma)) x.sigma <- 0.7^(abs(matrix(1:p,p,p) -  matrix(1:p,p,p,byrow=T)))
	if(missing(x)) x <- mvrnorm(n, mu=rep(0,p), Sigma=x.sigma)
	xx <- cbind(1,x)
	t0 <- exp(xx %*% beta.true)
	psi.all <- 2/t0
	chi.all <- 2*t0
	lambda.all <- rep(0,n)
	y <- rep(NA,n)
	if(type=="rgig") {
		for(i in 1:n.true) y[i] <- rgig(1, chi = chi.all[i], psi = psi.all[i], lambda = lambda.all[i])
	}
	if(type=="lnorm") {
		y[1:n.true] <- t0[1:n.true] * rlnorm(n.true,meanlog=0,sdlog=sd.lnorm)
	}
	if(n.true + 1 <= n) y[(n.true+1):n] <- rlnorm(n.cont, meanlog = outlier.par[1], sdlog = outlier.par[2])
	list(x=x, y=y, beta=beta.true, x.sigma=x.sigma, n.true=n.true, n.cont=n.cont)
}


