\name{rree}
\alias{rree}
\alias{predict.rree}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Robust Relative Error Estimation.
}
\description{
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
This function gives us the robust least product relative error (LPRE) estimator and robust least squares relative error (LSRE) estimator via gamma-likelihood from a "rree" object for fixed value of gamma.  
}
\usage{
rree(x, y, intercept=TRUE, gam, beta.init, type="LPRE", algorithm="MM",
     maxit=1000, cov.beta = TRUE, tol=sqrt(.Machine$double.eps))
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{
Matrix of predictors.
}
  \item{y}{
Vector of responses.
}
  \item{intercept}{
If TRUE, intercept is included.
}
  \item{gam}{
The value of gamma used in the gamma-likelihood function. If gam=0, the ordinary relative error loss function is minimized (i.e., likelihood function is maximized).
}
  \item{beta.init}{
Initial value fo beta. If missing, it becomes zero vector.
}
  \item{type}{
Either "LPRE" or "LSRE".  Details are presented in our paper.
}
  \item{algorithm}{
"MM" "BFGS", or "hybrid". With the hybrid, first MM algorithm is conducted, and then BFGS is used.  The hybrid is generally fast and stable.  The BFGS is the fastest but sometimes unstable.  The convergence of the MM is slow but MM is generally stable.
}
  \item{maxit}{
Maximum number of iterations in the MM algorithm.
}
  \item{cov.beta}{
If TRUE and type="LPRE", the asymptotic covariance matrix of estimator is computed.
}
  \item{tol}{
Threshold used for convergence of parameter.
}
%  \item{\dots}{Other graphical parameters to plot}
}
%\details{
%%  ~~ If necessary, more details than the description above ~~
%}
\value{
\item{beta}{Coefficient vector.}
\item{loss}{The value of loss criterion.}
\item{cov.beta}{Asymptotic covariance matrix of estimator.}
\item{weight}{Weights in the weighted log-likelihood.}
\item{intercept}{If TRUE, intercept is included.}
\item{x}{Matrix of predictors.}
\item{y}{Vector of responses.}
}
\references{
%% ~put references to the literature/web site here ~
%Friedman, J. (2008).  Fast sparse regression and classification. \eqn{Technical report}, Standford University.\cr
Hirose, K. and Masuda, H. (2018). 
Robust relative error estimation. \emph{manuscript}.
}
\author{
Kei Hirose\cr
\email{mail@keihirose.com}
}
%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{\code{predict.rree} and \code{rree.generator} objects.}

\examples{
#generate data
dat <- rree.generator(n=50, p=5, outlier.ratio=0.1) #about last 10% data values are outliers

#fitting
fit <- rree(dat$x, dat$y, gam=0) #ordinary LPRE
fit2 <- rree(dat$x, dat$y, gam=0.2) #robust LPRE with gamma=0.2
fit
fit2

#prediction
predict(fit2, newx=dat$x[1:10,])
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
